version 10
clear
capture log close
set more off
set memory 600m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_01.log, text replace

* Diese Datei: Beisp_01.do (20.06.2008)

* Beispiel 1: Designbasierte Schtzung des Gesamtwertes Zahl der Erwerbslosen

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */

use ef1 ef3 ef4 ef7 ef30 ef504 ef505 ef506 ef507 ef708 ef712 ///
    using mz02cf_Beisp.dta, clear

* Designdefinition (A)
gen schicht = ef1*10 + ef712 // Bundesland, Gebudegrenklasse 
gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5% 
gen w = 1/f           // Designgewicht

* Interessierende Variable: ILO-Erwerbslos (ef504)
gen y = ef504==2

* Subpopulation: Bevlkerung am Hauptwohnsitz (ef505), 15+ Jahre (ef30)
gen sub = ef505>=1 & ef505<=2 & ef30>=15

* 1a) Ohne Ausschluss von PSUs mit nur einer Sekundreinheit 
*     Voreinstellung Option:single(missing)
* Definition Stichprobendesign (A)
* - Einstufige Klumpenauswahl: PSU = Auswahlbezirk (ef3)
* - Schichtung: schicht = Bundesland (ef1), Gebudeschicht (ef712)
* - Endlichkeitskorrektur mit Auswahlsatz f = 0.01 * 0.035
* - Designgewicht: w (Inklusionswahrscheinlichkeiten MZ: 1% CF: 3,5%)
svyset ef3 [pw = w], strata(schicht) fpc(f)
* Schtzung des Gesamtwertes
svy linearized, subpop(sub) : total y

* 1b) Ausschluss von PSUs mit nur einer Sekundreinheit 
*     Option:singleunit(certainty)
svyset ef3 [pw = w], strata(schicht) fpc(f) single(certainty)
svy linearized, subpop(sub) : total y

* Problemflle: PSUs mit nur einer Sekundreinheit 
svydescribe, single gen(single)
list ef1 ef712 ef3 ef505 ef506 y sub if single, nolab noobs

* 1c) Rekodierung von PSUs mit nur einer Sekundreinheit in Pseudoschicht
gen pschicht = schicht
replace pschicht = 34 if single // Bremen & GU => Niedersachsen & GU
svyset ef3 [pw = w], strata(pschicht) fpc(f) single(missing)
svy linearized, subpop(sub) : total y

* 1d) Test alternativer Schtzungen
* (B) Einstufige Schtzung, Primreinheit=Wohnung, Auswahlsatz f = 0,00035
gen whg = ef3*10+ef7
svyset whg [pw = w], strata(schicht) fpc(f) single(certainty)
svy linearized, subpop(sub) : total y

* (C) Zweistufige Schtzung, 
*     1. Auswahlbezirk, Auswahlsatz f1 = 0,002376
*     2. Haushalt, Auswahlsatz      f2 = 0,00035 / f1 = 0,147
gen f1 = 10707/(45058/0.01)
gen f2 = f / f1
replace w = 1/(f1*f2)
svyset ef3 [pw=w], strata(schicht) fpc(f1) vce(linearized) singleunit(certainty) || ef4, fpc(f2)
svy linearized, subpop(sub) : total y

* (D) Zweistufige Schtzung, 
*     1. Auswahlbezirk, Auswahlsatz fMZ = 0,01
*     2. Haushalt, Auswahlsatz fCF = 0,035
gen f_MZ = 0.01
gen f_CF = 0.035
replace w = 1/(f_MZ * f_CF)
svyset ef3 [pw=w], strata(schicht) fpc(f_MZ) vce(linearized) singleunit(certainty) || ef4, fpc(f_CF)
svy linearized, subpop(sub) : total y


* === Erweiterte Schichtung ===
* + Gemeindegrenklasse (ef708) als Proxy fr Regionalschicht
gen schicht2 =  ef1*100 + ef708*10 + ef712 

* (A') Einstufige Schtzung, PSU=Auswahlbezirk, f = 0.01 * 0.035
replace w = 1/f
svyset ef3 [pw = w], strata(schicht2) fpc(f) single(certainty)
quietly svydescribe, stage(1) single gen(s_A)
* tab s_A
svy linearized, subpop(sub) : total y


* (B') Einstufige Schtzung, PSU=Wohnung, Auswahlsatz f = 0,00035
svyset whg [pw = w], strata(schicht2) fpc(f) single(certainty)
quietly: svydescribe, stage(1) single gen(s_C)
svy linearized, subpop(sub) : total y

* (C') Zweistufige Schtzung, PSU=Auswahlbezirk, f1 = 0,002376
*                             SECU=Haushalt, f2 = 0,00035 / f1 = 0,147
replace w = 1/(f1*f2)
svyset ef3 [pw=w], strata(schicht2) fpc(f1) vce(linearized) singleunit(certainty) || ef4, fpc(f2) 
quietly: svydescribe, stage(1) single gen(s_D1)
* tab s_D1
quietly: svydescribe, stage(2) single gen(s_D2)
* tab s_D2
svy linearized, subpop(sub) : total y

* (D') Zweistufige Schtzung, PSU=Auswahlbezirk, f_MZ= 0,01
*                             SECU=Haushalt, f_CF = 0,035
replace w = 1/(f_MZ * f_CF)
svyset ef3 [pw=w], strata(schicht2) fpc(f_MZ) vce(linearized) singleunit(certainty) || ef4, fpc(f_CF) 
quietly: svydescribe, stage(1) single gen(s_E1)
* tab s_E1
quietly: svydescribe, stage(2) single gen(s_E2)
* tab s_E2
svy linearized, subpop(sub) : total y

exit


/* Beispiel 1 im Scientific Use File MZ 2002
* Einstufige Schtzung 
* (...)
gen f1 = 0.01         // Auswahlsatz PSU:  1%
gen f2 = 0.70         // Auswahlsatz HH:  70%
gen w  = 1/(f1*f2)    // Designgewicht 1% * 70%
svyset ef3 [pw = w], strata(schicht) fpc(f1)
* svydescribe, stage(1) single gen(s1)
svy linearized, subpop(sub) : total y

* Zweistufige Schtzung
svyset ef3 [pw = w], strata(schicht) fpc(f1) || ef4, fpc(f2)
svydescribe, stage(2) single gen(s2)
svyset ef3 [pw = w], strata(schicht) fpc(f1) ///
    || ef4, fpc(f2) single(certainty)
svy linearized, subpop(sub) : total y
*/

