version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_04.log, text replace

* Diese Datei: Beisp_04.do (20.06.2008)  

* Beispiel 4: Gruppenvergleiche

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */


use ef1 ef3 ef4 ef30 ef32 ef504 ef505 ef506 ef708 ef712 ///
    using mz02cf_Beisp.dta, clear

* Schichtung: Bundesland (ef1), Gebudegrenklasse (ef712)
gen schicht = ef1*10 + ef712
gen f = 0.01 * 0.035
gen w = 1/f
svyset ef3 [pw=w] , strata(schicht) fpc(f) singleunit(certainty)

* Interessierende Variable: ILO-Erwerbslos (ef504)
recode ef504 (2=1 "Erwerbslos") (*=0 "Sonst"), gen(y)
label var y "ILO-Erwerbsstatus" // nur bei Verwendung "sub" !

* Subpopulation: Bevlkerung am Hauptwohnsitz (ef505), 15-65 Jahre (ef30), Erwerbspers.
gen sub = ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504<=2

* West-/Ostdeutschland
recode ef1 (1/11=1 "West") (*=2 "Ost"), gen(westost)
replace westost = 2 if ef708==9  /* Ost-Berlin */
label var westost "West-/Ostdeutschland" 

* Schtzung des Gesamtwertes Zahl der Erwerbslosen
svy linearized, subpop(sub) : total y

* ... in West-/Ostdeutschland 
svy linearized, subpop(sub) : total y, over(westost)


* ... Fallzahltabelle
svy linearized, subpop(sub) : tabulate y westost, count ///
                format(%8.0f) cellwidth(10) stubwidth(20)

* ... mit Spalten-% und Unabhngigkeitstest
svy linearized, subpop(sub): tabulate y westost, col ///
    deft pearson  format(%5.3f) cellwidth(15) stubwidth(20)

exit
