version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_05.log, text replace

* Diese Datei: Beisp_05.do (22.05.2008)

* Beispiel 5: Gesamtwerte mit gebundener Hochrechnung

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */


use ef1 ef3 ef30 ef32 ef52 ef127 ef504 ef505 ef712 ef750g ///
    using mz02cf_Beisp.dta, replace 

* Variablenabgenzungen analog zu Beispiel 1b und 3a
gen schicht = ef1*10 + ef712   // Bundesland + Gebudegrenklasse
gen f = 0.01 * 0.035           // Auswahlsatz MZ 1%, CF 3,5%
gen w = 1/f                    // Designgewicht
gen sub = ef505<=2 & ef30>=15  // Bev. am Hauptwohnsitz, 15+ Jahre
gen y = ef504==2 * sub         // ILO-Erwerbslos & Subpopulation

* Gesamtwert designgewichtet
svyset ef3 [pw = w], strata(schicht) fpc(f) ///
                     single(certainty)
svy linearized, subpop(sub) : total y , noheader
* Ergebnisse speichern
matrix t_d = e(b)   // Gesamtwert
svmat  t_d          //   Matrix -> Variable
matrix v_d = e(V)   // Varianz
svmat  v_d          //   Matrix -> Variable
disp "CV (%) = " (v_d^.5 * 100)/t_d   // Variationskoeffizient

* Vorbereitung Poststratifikation
* 1a) Anpassung: Geschl. * Staatsangeh., Sold., Wehrpfl.
gen anp=(1*(ef32==1 & ef52==1 & ef127~=9 & ef127~=10)) /// 
      + (2*(ef32==2 & ef52==1)) ///
      + (3*(ef32==1 & ef52~=1)) ///
      + (4*(ef32==2 & ef52~=1)) ///
      + (5*(ef32==1 & ef52==1 & ef127==9)) ///
      + (6*(ef32==1 & ef52==1 & ef127==10))
lab var anp "Anpassungsklassen"
lab def anp 1 "Deutsche Maenner"  2 "Deutsche Frauen" ///
              3 "Ausl. Maenner"     4 "Ausl. Frauen" ///
              5 "Zeit-/Berufssold." 6 "Wehrpflichtige"
label val anp anp
* 1b) Proxy Anpassungsschicht
gen anpschicht=sub*(ef1*10+anp) /* nur fr Subpop */
lab var anpschicht "Anpassungschicht - Proxy"

* 2)  Populationsdaten pro Anpassungsschicht 
* egen  M_k = total(ef750g*100*(ef505<=2)), by(anpschicht)
* in zwei Schritten:
gen w_anp   = ef750g*100*(ef505<=2)   // Bevlkerung am Hauptwohnsitz 
egen    M_k = total(w_anp), by(anpschicht)

* Total gebundene Hochrechnung
svyset ef3 [pw = w], strata(schicht) fpc(f) single(certainty) ///
                     poststrata(anpschicht) postweight(M_k) 
svy linearized, subpop(sub) : total y 
matrix t_p = e(b)
svmat  t_p
matrix v_p = e(V)
svmat  v_p
disp "CV (%) = " (v_p^.5 * 100)/t_p

* 3) Umsetzung der Stata-Formeln 
egen M_Dach_k = total(w*sub), by(anpschicht) 
gen w_post = M_k/M_Dach_k*w                 /* w*_j  */
replace w_post = 0 if sub==0
gen y_post = w_post*y
* Gesamtwert y_post: poststratifiziert 
* <=> Abweichung z.B. zu: tab y if sub [iw=w_anp]
table y if y & sub, c(sum y_post sum w_anp)

* V(Y_post) fr Hilfsmerkmal (score variable) z
egen Y_Dach_k = total(w*y*sub), by(anpschicht)
gen z = sub*(M_k/M_Dach_k) * (y - (Y_Dach_k/M_Dach_k))
replace z=0 if z==.
svyset ef3 [pw = w], strata(schicht) fpc(f) ///
                     single(certainty) 
* "Total" irrelevant, nur S.E. interessiert
quietly: svy linearized, subpop(sub) : total z, noheader
matrix v_z = e(V)
svmat  v_z
disp "s.e. (z) = " v_z^.5

/* ------------------------------------------------------------------------
Problem:  Gesamtwert der gebundenen Hochrechnung stimmt nicht mit
          gewichteter Tabellierung berein (z.B. tab y if sub [iw=w_anp] 
          bzw. (in 100): (...) [iw=ef750g]), da sich Hochrechnungsfaktoren
          insgesamt bzw. der Subpopulation von den Hochrechnungsfaktoren
          fr y unterscheiden.
Lsung:   Direkte Verwendung des Korrekturfaktors ("Soll durch Ist") fr y 
          und bertragung auf die Sub-/Population.
Ergebnis: Gesamtwert der SVY-Auswertung mit gebundener Hochrechnung
          entspricht einfacher gewichteter Auswertung. 
          Standardfehler knnen sich je nach Gewichtung unterscheiden.
          Allerdings ndern sich Schtzungen der Population und
          Subpopulation ("Population size" u. "Subpop. size").
--------------------------------------------------------------------------- */
egen wy = total(ef750g*0.035*y), by(anpschicht) 
egen ny = total(y), by(anpschicht)
gen  g_y = wy/ny // Korrekturfaktor der y-Werte
recode g_y (.=0)
gen w_y = g_y*w  // Endgewicht = Korrekturfaktor * Designgewicht
egen M_k2 = total(w_y), by(anpschicht)
svyset ef3 [pw=w], strata(schicht) fpc(f) single(certainty) ///
                   poststrata(anpschicht) postweight(M_k2) 
svy linearized, subpop(sub) : total y 
matrix t_k = e(b)
svmat  t_k
matrix v_k = e(V)
svmat  v_k
disp "CV (%) = " (v_k^.5 * 100)/t_k

exit
