version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_06.log, text replace

* Diese Datei: Beisp_06.do (22.05.2008)

* Beispiel 6: Gesamtwerte mit gebundener Hochrechnung (Regressionsschtzung)

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */


use ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef504 ef505 ef712 ef750g ///
    using mz02cf_Beisp.dta, replace 

gen schicht = ef1*10 + ef712 
gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5%
gen d = 1/f           // Designgewicht 
gen sub = ef505<=2 & ef30>=15 /* Bev. am Hauptwohnsitz, 15+ Jahre */
gen y = ef504==2 * sub        /* ILO-Erwerbslos & Subpopulation */

* 1) Proxy Anpassungsschicht
gen anp=(1*(ef32==1 & ef52==1 & ef127~=9 & ef127~=10)) /// Deutsche Mnner
      + (2*(ef32==2 & ef52==1)) /// Deutsche Frauen
      + (3*(ef32==1 & ef52~=1)) /// Auslndische Mnner
      + (4*(ef32==2 & ef52~=1)) /// Auslndische Frauen
      + (5*(ef32==1 & ef52==1 & ef127==9)) /// Zeit-/Berufssoldaten
      + (6*(ef32==1 & ef52==1 & ef127==10)) // Wehrpflichtige
gen anpschicht=sub*(ef1*10+anp) /* nur fr Subpop */
lab var anpschicht "Anpassungschicht - Proxy"

* 2) Berechnen des Regressionskoeffizienten mit Regression y  "Erwerbslos"
*    auf X "Hilfsmerkmale" bzw. "Anpassungsschicht"
*       xi: regress y i.anpschicht if sub, 
*       predict B_Dach if e(sample), xb
*       replace B_Dach = 0 if B_Dach==.
* Da Anpassungsschichten disjunkt: B-Dach_g = y-quer_s_g = y_Dach.
* Einfacher:
egen B_Dach = mean(y), by(anpschicht)

* [A] Gewichtung analog Beispiel 5 (w_anp)
*  3) Berechnung des gewichteten Gesamtwertes ber die Anpassungsschichten
*       ef750g rechnet auf 100 in Population hoch 
egen    M_k   = total(ef750g*100*(ef505<=2)), by(anpschicht) // Populationswerte geb. Hochrechnung
egen M_Dach_k = total(d*(ef505<=2)), by(anpschicht) // Populationswerte designgewichtet
gen g1 = M_k/M_Dach_k     // Korrekturfaktor g_k
replace g1 = 0 if sub==0
gen  w1 = d*g1            // Endgewicht w_k
egen t_y1 = total(y*w1)
disp "Gewichteter Gesamtwert t_y1 = " t_y1 

*  4) Varianzschtzung mit Hilfsvariable u 
gen u1 = g1*(y-B_Dach)
svyset ef3 [pw = d], strata(schicht) fpc(f) single(certainty)
*  "total" irrelevant
svy linearized, subpop(sub) : total u1 , noheader

* [B] Gewichtung analog Beispiel 5 (w_y)
egen wy = total(ef750g*0.035*y), by(anpschicht) 
egen ny = total(y), by(anpschicht)
gen  g2 = wy/ny // Korrekturfaktor der y-Werte
recode g2 (.=0)
gen w2 = g2*d  // Endgewicht = Korrekturfaktor * Designgewicht
egen t_y2 = total(y*w2)
disp "Gewichteter Gesamtwert t_y2 = " t_y2
gen u2    = g2*(y-B_Dach)
svyset ef3 [pw = d], strata(schicht) fpc(f) single(certainty)
svy linearized, subpop(sub) : total u2 , noheader

* [C] Gewichtung mit ef750 direkt (ohne Normierung auf 1%-MZ) analog zu
*     frheren Programmen (Rendtel/Schimpl-Neimanns 2001); z.B. varmz_a.do
gen  g3 = ef750g*0.035*sub 
gen  w3 = d*g3
egen t_y3 = total(y*w3)
disp "Gewichteter Gesamtwert t_y3 = " t_y3
gen u3    = g3*(y-B_Dach)
svyset ef3 [pw = d], strata(schicht) fpc(f) single(certainty)
svy linearized, subpop(sub) : total u3 , noheader

exit

/* ---------------------------------------------------------------
* Beispiel 6 [C] mit Scientific Use File MZ 2002
* - im SUF abweichende Definitionen -
gen f = 0.01
gen d = 1/(0.01 * 0.70)   // Designgewicht 
gen g = ef750*sub         // Korrekturfaktor
gen w = d*g               // Endgewicht
egen t_y = total(y*w)       // Gewichteter Gesamtwert
gen u    = g*(y-B_Dach)   // Hilfsvariable v. Varianzschtzung
svyset ef3 [pw = d], strata(schicht) fpc(f) single(certainty)
svy linearized, subpop(sub) : total u , noheader
* SUF-Ergebnisse:  Gesamtwert = 3.492.013    S.E. = 26.685  
--------------------------------------------------------------- */


