version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_07.log, text replace

* Diese Datei: Beisp_07.do (22.05.2008)

* Beispiel 7: Erwerbslosenquote mit Designgewichtung 

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */


use ef1 ef3 ef4 ef30 ef32 ef52 ef127 ef504 ef505 ef708 ef712 ef750g ///
    using mz02cf_Beisp.dta, replace 

* Variablenabgenzungen analog zu Beispiel 4
gen schicht = ef1*10 + ef712 
gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5% 
gen w = 1/f           // Designgewicht

recode ef1 (1/11=1 "West") (*=2 "Ost"), gen(westost)
replace westost = 2 if ef708==9
recode ef30 (0/14=0 "0-14")   (15/24=1 "15-24") ///
            (25/54=2 "25-54") (55/65=3 "55-65") ///
            (66/99=4 "66+"), gen(alter)

* sub: Bevlkerung am Hauptwohnsitz, 15-65 Jahre, Erwerbspersonen
gen sub = ef505>=1 & ef505<=2 & ef30>=15 & ef30<=65 & ef504>=1 & ef504<=2
gen y = (ef504==2) * sub            //Erwerbslose
gen x = (ef504>=1 & ef504<=2) * sub // Erwerbspersonen

* Erwerbslosenquote nach Altersgruppen
svyset ef3 [pw=w] , strata(schicht) fpc(f) singleunit(certainty)
quietly: svy linearized, subpop(sub) : ///
               ratio (Erwerbslosenquote: y/x), over(alter)
estat effects, deft
* Variationskoeffizienten (cv)
matrix ta = e(b)
matrix va = e(V)
matrix cva = sqrt(va[1,1])/ta[1,1] , sqrt(va[2,2])/ta[1,2], ///
             sqrt(va[3,3])/ta[1,3]
matrix list cva

* Erwerbslosenquote nach Region und Altersgruppen
quietly: svy linearized, subpop(sub) : ///
         ratio (Erwerbslosenquote: y/x), over(westost alter)
estat effects, deft

* Wald-Tests 
* Erwerbslosenquote 15-24-Jhriger: West = Ost ?
test [Erwerbslosenquote]_subpop_1 = [Erwerbslosenquote]_subpop_4

* Erwerbslosenquote 55-65-Jhriger: West = Ost ?
test [Erwerbslosenquote]_subpop_3 = [Erwerbslosenquote]_subpop_6

exit
