version 10
clear
capture log close
set more off
set memory 200m
set dp comma

* cd <Arbeitsverzeichnis>

log using Beisp_10.log, text replace

* Diese Datei: Beisp_10.do (22.05.2008)

* Beispiel 10: Durchschnittliche Arbeitsstunden mit gebundener Hochrechnung (Poststratifikation) 

/* Quelle:
Schimpl-Neimanns, Bernhard: Schtzung des Stichprobenfehlers im 
Mikrozensus mit Stata - Eine Einfhrung mit Beispielen zum Campus 
File Mikrozensus 2002. GESIS-Methodenbericht 2009/02. Mannheim: GESIS
URL: http://www.gesis.org/fileadmin/upload/forschung/publikationen/
     gesis_reihen/gesis_methodenberichte/2009/gesis_mb_09_02.pdf
Diese Datei:
     http://www.gesis.org/dienstleistungen/tools-standards/mikrodaten-tools/
     sp-fehler/Stata_Beispiele.zip */


use ef1 ef3 ef32 ef52 ef127 ef141 ef504 ef505 ef708 ef712 ef750g ///
    using mz02cf_Beisp.dta, replace 

* Variablenabgenzungen analog zu Beispiel 4
gen schicht = ef1*10 + ef712 
gen f = 0.01 * 0.035  // Auswahlsatz MZ 1%, CF 3,5%
gen w = 1/f           // Designgewicht

* sub: Bevlkerung am Hauptwohnsitz, Erwerbsttige
gen sub = ef505<=2 & ef504==1

* ef141 Normalerw. geleist. Arbeitszeit (Std.) je Woche
recode ef141 (57=58) (60=62) (65=67) (70=72) (75=77) ///
             (80=82) (85=87) (90=93.5) (.=0), gen(y) copyrest

*   westost: West-/Ostdeutschland
recode ef1 (1/11=1 "West") (*=2 "Ost"), gen(westost)
replace westost = 2 if ef708==9

* Proxy Anpassungsschicht
gen anp=(1*(ef32==1 & ef52==1 & ef127~=9 & ef127~=10)) /// Deutsche Mnner
      + (2*(ef32==2 & ef52==1)) /// Deutsche Frauen
      + (3*(ef32==1 & ef52~=1)) /// Auslndische Mnner
      + (4*(ef32==2 & ef52~=1)) /// Auslndische Frauen
      + (5*(ef32==1 & ef52==1 & ef127==9)) /// Zeit-/Berufssoldaten
      + (6*(ef32==1 & ef52==1 & ef127==10)) // Wehrpflichtige
gen anpschicht=sub*(ef1*10+anp) /* nur fr Subpop */

* Populationsdaten pro Anpassungsschicht (wie [A] in Beisp_06.do)
egen M_k = total(ef750g*100*(ef505<=2)), by(anpschicht) 

* Mittelwert Arbeitszeit mit gebundener Hochrechnung
svyset ef3 [pw = w], strata(schicht) fpc(f) ///
   single(certainty)  poststrata(anpschicht) postweight(M_k)
svy linearized, subpop(sub) : mean y,  over(ef32 westost)

exit
